@@ -8,6 +8,7 @@
  * Authors:
  * - Thomas Beermann, <thomas.beermann@cern.ch>, 2014-2019
  * - Mario Lassnig, <mario.lassnig@cern.ch>, 2014
+ * - Martin Barisits, <martin.barisits@cern.ch>, 2021
  */
 
 var ids = null;
@@ -219,24 +220,6 @@ function link_to_new_atlas_dashboard(file, scope, rse) {
     return url;
 }
 
-function link_to_old_atlas_dashboard(file, scope, rse) {
-    var items = rse.split("_");
-    var site = items.slice(0,-1).join('_');
-    var token = items.slice(-1)[0];
-    var link = "http://dashb-atlas-ddm-old.cern.ch/ddm2/#d.dst.site=";
-    link += site;
-    link += "&d.dst.token=";
-    link += token;
-    link += "&d.name=";
-    link += file;
-    link += "&d.scope=";
-    link += scope;
-    link += "&grouping.dst=%28site,token%29&tab=details";
-
-    url = '<a target="_blank" href=' + link + ">old</a>";
-    return url;
-}
-
 
 function show_details(file_data) {
     columns = [{'data': 'name'},
@@ -283,7 +266,7 @@ function show_details(file_data) {
         $.each(sorted_rses, function(index, rse) {
             var state = rses[rse];
             str_rses += "<font color=";
-            dashboard += "<div>" + link_to_new_atlas_dashboard(name, scope, rse) + " (" + link_to_old_atlas_dashboard(name, scope, rse) + ")</div>";
+            dashboard += "<div>" + link_to_new_atlas_dashboard(name, scope, rse) + "</div>";
             if (state == 'OK') {
                 str_rses += "green>" + rse;
                 ftsmon += '<div style="visibility: hidden;">.</div>';
@@ -425,7 +408,7 @@ function load_examine() {
     r.examine_rule({
         'rule_id': url_param('rule_id'),
         success: function(data) {
-            $("#examine_details").append("<table id=\"dt_examine\" class=\"compact stripe order-column cell-border\" style=\"word-wrap: break-word;\"><thead><th>Filename</th><th>RSEs</th><th>Attempts</th><th>Last Retry</th><th>Last Error</th><th>Last Source</th><th>Available Source</th><th>Blacklisted Sources</th></thead><tfoot><th>Filename</th><th>RSEs</th><th>Attempts</th><th>Last Retry</th><th>Last Error</th><th>Last Source</th><th>Available Source</th><th>Blacklisted Sources</th></tfoot></table>");
+            $("#examine_details").append("<table id=\"dt_examine\" class=\"compact stripe order-column cell-border\" style=\"word-wrap: break-word;\"><thead><th>Filename</th><th>RSEs</th><th>Attempts</th><th>Last Retry</th><th>Last Error</th><th>Last Source</th><th>Available Source</th><th>Blocklisted Sources</th></thead><tfoot><th>Filename</th><th>RSEs</th><th>Attempts</th><th>Last Retry</th><th>Last Error</th><th>Last Source</th><th>Available Source</th><th>Blocklisted Sources</th></tfoot></table>");
             var dt = $('#dt_examine').DataTable( {
                 bAutoWidth: false,
                 fnDrawCallback:update_links,
@@ -436,22 +419,22 @@ function load_examine() {
                           {'data': 'last_error'},
                           {'data': 'last_source'},
                           {'data': 'available_srcs'},
-                          {'data': 'blacklisted_srcs'}
+                          {'data': 'blocklisted_srcs'}
                          ],
                 oLanguage: {'sSearch': 'Search by name, RSE or state'}
             });
             $.each(data['transfers'], function(index, lock) {
                 available_srcs = "";
-                blacklisted_srcs = "";
+                blocklisted_srcs = "";
                 $.each(lock['sources'], function(index, src) {
                     if (src[1] == true) {
                         available_srcs += src[0] + ', ';
                     } else {
-                        blacklisted_srcs += src[0] + ', ';
+                        blocklisted_srcs += src[0] + ', ';
                     }
                 });
                 lock['available_srcs'] = available_srcs.slice(0, -2);
-                lock['blacklisted_srcs'] = blacklisted_srcs.slice(0, -2);
+                lock['blocklisted_srcs'] = blocklisted_srcs.slice(0, -2);
                 dt.row.add(lock);
             });
             dt.order([0, 'asc']).draw();
